@@ -16,7 +16,7 @@ from yaml import MappingNode
 from yaml.constructor import SafeConstructor
 from yaml.constructor import ConstructorError
 import cfnlint
-from cfnlint.decode.node import str_node, dict_node, list_node
+from cfnlint.decode.node import str_node, dict_node, list_node, sub_node
 
 try:
     from yaml.cyaml import CParser as Parser  # pylint: disable=ungrouped-imports
@@ -106,6 +106,11 @@ class NodeConstructor(SafeConstructor):
             mapping[key] = value
 
         obj, = SafeConstructor.construct_yaml_map(self, node)
+
+        if len(mapping) == 1:
+            if 'Fn::Sub' in mapping:
+                return sub_node(obj, node.start_mark, node.end_mark)
+
         return dict_node(obj, node.start_mark, node.end_mark)
 
     def construct_yaml_str(self, node):
@@ -191,6 +196,9 @@ def multi_constructor(loader, tag_suffix, node):
     else:
         raise 'Bad tag: !{}'.format(tag_suffix)
 
+    if tag_suffix == 'Fn::Sub':
+        return sub_node({tag_suffix: constructor(node)}, node.start_mark, node.end_mark)
+
     return dict_node({tag_suffix: constructor(node)}, node.start_mark, node.end_mark)
 
 
