@@ -4,6 +4,7 @@ SPDX-License-Identifier: MIT-0
 """
 from functools import reduce  # pylint: disable=redefined-builtin
 import re
+import copy
 import six
 from cfnlint.rules import CloudFormationLintRule
 from cfnlint.rules import RuleMatch
@@ -17,40 +18,6 @@ class SubNeeded(CloudFormationLintRule):
     source_url = 'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/intrinsic-function-reference-sub.html'
     tags = ['functions', 'sub']
 
-    # Free-form text properties to exclude from this rule
-    excludes = ['UserData', 'ZipFile', 'Condition', 'AWS::CloudFormation::Init',
-                'CloudWatchAlarmDefinition', 'TopicRulePayload', 'BuildSpec',
-                'RequestMappingTemplate', 'LogFormat', 'TemplateBody', 'ResponseMappingTemplate',
-                'RouteSelectionExpression']
-    api_excludes = ['Uri', 'Body', 'ConnectionId']
-
-
-    # IAM Policy has special variables that don't require !Sub, Check for these
-    # https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_variables.html
-    # https://docs.aws.amazon.com/iot/latest/developerguide/basic-policy-variables.html
-    # https://docs.aws.amazon.com/iot/latest/developerguide/thing-policy-variables.html
-    # https://docs.aws.amazon.com/transfer/latest/userguide/users.html#users-policies-scope-down
-    # https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html
-    resource_excludes = ['${aws:CurrentTime}', '${aws:EpochTime}',
-                         '${aws:TokenIssueTime}', '${aws:principaltype}',
-                         '${aws:SecureTransport}', '${aws:SourceIp}',
-                         '${aws:UserAgent}', '${aws:userid}',
-                         '${aws:username}', '${ec2:SourceInstanceARN}',
-                         '${iot:Connection.Thing.ThingName}',
-                         '${iot:Connection.Thing.ThingTypeName}',
-                         '${iot:Connection.Thing.IsAttached}',
-                         '${iot:ClientId}', '${transfer:HomeBucket}',
-                         '${transfer:HomeDirectory}', '${transfer:HomeFolder}',
-                         '${transfer:UserName}', '${redshift:DbUser}',
-                         '${cognito-identity.amazonaws.com:aud}',
-                         '${cognito-identity.amazonaws.com:sub}',
-                         '${cognito-identity.amazonaws.com:amr}']
-
-    # https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-iam-access-control-identity-based.html
-    condition_excludes = [
-        '${redshift:DbUser}',
-    ]
-
     def __init__(self):
         """Init"""
         super(SubNeeded, self).__init__()
@@ -110,61 +77,46 @@ class SubNeeded(CloudFormationLintRule):
     def match(self, cfn):
         matches = []
 
+        refs = cfn.get_valid_refs()
+        getatts = cfn.get_valid_getatts()
+
         # Get a list of paths to every leaf node string containing at least one ${parameter}
         parameter_string_paths = self.match_values(cfn)
         # We want to search all of the paths to check if each one contains an 'Fn::Sub'
         for parameter_string_path in parameter_string_paths:
-            if parameter_string_path[0] in ['Parameters']:
-                continue
-            # Exclude the special IAM variables
-            variable = parameter_string_path[-1]
-
-            if 'Resource' in parameter_string_path:
-                if variable in self.resource_excludes:
-                    continue
-            if 'NotResource' in parameter_string_path:
-                if variable in self.resource_excludes:
-                    continue
-            if 'Condition' in parameter_string_path:
-                if variable in self.condition_excludes:
-                    continue
+            # Get variable
+            var = parameter_string_path[-1]
 
             # Step Function State Machine has a Definition Substitution that allows usage of special variables outside of a !Sub
             # https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-stepfunctions-statemachine-definitionsubstitutions.html
 
             if 'DefinitionString' in parameter_string_path:
-                modified_parameter_string_path = parameter_string_path
+                modified_parameter_string_path = copy.copy(parameter_string_path)
                 index = parameter_string_path.index('DefinitionString')
                 modified_parameter_string_path[index] = 'DefinitionSubstitutions'
                 modified_parameter_string_path = modified_parameter_string_path[:index+1]
-                modified_parameter_string_path.append(variable[2:-1])
+                modified_parameter_string_path.append(var[2:-1])
                 if reduce(lambda c, k: c.get(k, {}), modified_parameter_string_path, cfn.template):
                     continue
 
             # Exclude variables that match custom exclude filters, if configured
             # (for third-party tools that pre-process templates before uploading them to AWS)
-            if self._variable_custom_excluded(variable):
+            if self._variable_custom_excluded(var):
                 continue
 
             # Exclude literals (https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/intrinsic-function-reference-sub.html)
-            if variable.startswith('${!'):
+            if var.startswith('${!'):
                 continue
 
-            found_sub = False
-            # Does the path contain an 'Fn::Sub'?
-            for step in parameter_string_path:
-                if step in self.api_excludes:
-                    if self._api_exceptions(parameter_string_path[-1]):
-                        found_sub = True
-                elif step == 'Fn::Sub' or step in self.excludes:
-                    found_sub = True
+            var_stripped = var[2:-1].strip()
 
             # If we didn't find an 'Fn::Sub' it means a string containing a ${parameter} may not be evaluated correctly
-            if not found_sub:
-                # Remove the last item (the variable) to prevent multiple errors on 1 line errors
-                path = parameter_string_path[:-1]
-                message = 'Found an embedded parameter "{}" outside of an "Fn::Sub" at {}'.format(
-                    variable, '/'.join(map(str, path)))
-                matches.append(RuleMatch(path, message))
+            if not 'Fn::Sub' in parameter_string_path:
+                if (var_stripped in refs or var_stripped in getatts) or 'DefinitionString' in parameter_string_path:
+                    # Remove the last item (the variable) to prevent multiple errors on 1 line errors
+                    path = parameter_string_path[:-1]
+                    message = 'Found an embedded parameter "{}" outside of an "Fn::Sub" at {}'.format(
+                        var, '/'.join(map(str, path)))
+                    matches.append(RuleMatch(path, message))
 
         return matches
